==> haskell-hls-graph-2.1.0.0-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.1.0.0
visibility:           public
id:                   hls-graph-2.1.0.0-5U8GhOEUOVs1VPqnAQOCwo
key:                  hls-graph-2.1.0.0-5U8GhOEUOVs1VPqnAQOCwo
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  334194bcf9687e33d7713548732d5a53
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-graph-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-graph-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-graph-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.1.0.0-5U8GhOEUOVs1VPqnAQOCwo
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    async-2.2.5-A7cw4gHfrNnBMjsgvHD8kq base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-LWra3MmVE7hIjr4mBFp6lZ filepath-1.4.300.1
    focus-1.0.3.2-HMVLoUfwQdv6aHCVz6BPOB
    hashable-1.4.7.0-L2Cc1YdcpYH9U2sZW5osde
    js-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
    js-flot-0.8.3-CSwWF2xMOrpIfADJpYok8C
    js-jquery-3.7.1-HiilPi5Njf83BjwRUk7lNl
    list-t-1.0.5.7-EM5zr1thpvoLHIkxHFphV1 stm-2.5.1.0
    stm-containers-1.2.1.1-Bj6tUNM1pEnDMZe8gYOJ0b text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-3TtWVZXyXmG4sYXTMcHi9s
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-graph-2.1.0.0-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.1.0.0
visibility:           public
id:                   hls-graph-2.1.0.0-fPrjqz8fg9GUEkiCv9S6a
key:                  hls-graph-2.1.0.0-fPrjqz8fg9GUEkiCv9S6a
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  f8c856ece43f3e49e8b3fb82dd0b3300
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-graph-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-graph-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-graph-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.1.0.0-fPrjqz8fg9GUEkiCv9S6a
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    async-2.2.5-A7cw4gHfrNnBMjsgvHD8kq base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-LWra3MmVE7hIjr4mBFp6lZ filepath-1.4.300.1
    focus-1.0.3.2-HMVLoUfwQdv6aHCVz6BPOB
    hashable-1.4.7.0-L2Cc1YdcpYH9U2sZW5osde
    js-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
    js-flot-0.8.3-CSwWF2xMOrpIfADJpYok8C
    js-jquery-3.7.1-zNbH83zcPMI8jK7fh3FHJ
    list-t-1.0.5.7-EM5zr1thpvoLHIkxHFphV1 stm-2.5.1.0
    stm-containers-1.2.1.1-Bj6tUNM1pEnDMZe8gYOJ0b text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-3TtWVZXyXmG4sYXTMcHi9s
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
